@@ -9,7 +9,7 @@ import math
 import time
 import threading
 import heapq
-from contextlib import ExitStack
+from contextlib import ExitStack, suppress
 import boto3
 import botocore
 import WDL
@@ -110,7 +110,7 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
         ), "Missing AWS Batch job queue configuration ([aws] task_queue / MINIWDL__AWS__TASK_QUEUE)"
 
         # TODO: query Batch compute environment for resource limits
-        cls._resource_limits = {"cpu": 64, "mem_bytes": 261992870916}
+        cls._resource_limits = {"cpu": 9999, "mem_bytes": 999999999999999}
         cls._submit_lock = threading.Lock()
         cls._last_submit_time = [0.0]
         cls._init_time = time.time()
@@ -156,7 +156,6 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
 
     def __init__(self, cfg, run_id, host_dir):
         super().__init__(cfg, run_id, host_dir)
-        self._observed_states = set()
         self._logStreamName = None
         self._inputs_copied = False
         # We'll direct Batch to mount EFS inside the task container at the same location we have
@@ -195,14 +194,17 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
             time.sleep(cooldown)
 
         rmtree_atomic(self.host_work_dir())
+        with suppress(FileNotFoundError):
+            os.unlink(self.host_stderr_txt() + ".offset")  # PygtailLogger state file
         super().reset(logger)
 
     def _run(self, logger, terminating, command):
         """
         Run task
         """
+        self._observed_states = set()
+        boto3_retries = self.cfg.get_dict("aws", "boto3_retries")
         try:
-            boto3_retries = self.cfg.get_dict("aws", "boto3_retries")
             aws_batch = boto3.Session().client(  # Session() needed for thread safety
                 "batch",
                 region_name=self._region_name,
@@ -312,6 +314,7 @@ class BatchJob(WDL.runtime.task_container.TaskContainer):
                 {"type": "VCPU", "value": str(vcpu)},
                 {"type": "MEMORY", "value": str(memory_mbytes)},
             ],
+            "privileged": self.runtime_values.get("privileged", False),
         }
 
         if self.cfg["task_runtime"].get_bool("as_user"):
